==> 0.0.1.tar.gz: lib/cashfree_pg.dart <==
library cashfree_pg;

import 'dart:async';
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:webview_flutter/webview_flutter.dart';

class CashfreePGSDK {
  Future<dynamic> doPayment(BuildContext context, Map<String, String> inputs, String mode) async {
    var completer = new Completer();
    completer.complete(Navigator.push(
        context,
        MaterialPageRoute(builder: (context) => PaymentScreen(inputs, Colors.white, Colors.black, mode))));
//        print("SDK Result : $result");
    return completer.future;
  }
  void doPaymentWithTheme(BuildContext context, Map<String, String> inputs, Color color1, Color color2, String mode) async {
    final result = await Navigator.push(
      context,
      MaterialPageRoute(builder: (context) => PaymentScreen(inputs, color1, color2, mode)),);
    print("SDK Result : $result");
  }
}


class PaymentScreen extends StatefulWidget {
  Map<String, String> _inputs;
  Color _color1;
  Color _color2;
  String _mode;
  PaymentScreen(Map<String, String> inputs, Color color1, Color color2, String mode) {
    _inputs = inputs;
    _color1 = color1;
    _color2 = color2;
    _mode = mode;
  }

  @override
  _PaymentScreenState createState() => _PaymentScreenState();
}

class _PaymentScreenState extends State<PaymentScreen> {
  final Completer<WebViewController> _controller =
  Completer<WebViewController>();

  String formHtml () {
    final url = widget._mode == "TEST" ? 'https://test.cashfree.com/billpay/checkout/post/submit' : 'https://www.cashfree.com/checkout/post/submit';
    String htmlStr = "<html>"
        "<body onload='document.order.submit()'>"
        "<form name='order' action='$url' method='post'>";
    widget._inputs.forEach((String key, String val) => htmlStr += '''<input type="hidden" name="$key" value="$val" />''');
    htmlStr +=
    "<input type='hidden' name='source' value='iossdk'/>"
        "<input type='hidden' name='hideHeader' value='1'/>"
        "</form>"
        "</body>"
        "</html>";
    print(htmlStr);
    return htmlStr;
  }

  _PaymentScreenState();
  Future<bool> _onWillPop() {
    return showDialog(
      context: context,
      builder: (context) => new AlertDialog(
        title: new Text('Are you sure?'),
        content: new Text('Do you want to abort payment'),
        actions: <Widget>[
          new FlatButton(
            onPressed: () => Navigator.of(context).pop(false),
            child: new Text('No'),
          ),
          new FlatButton(
            onPressed: () => Navigator.of(context).pop(true),
            child: new Text('Yes'),
          ),
        ],
      ),
    ) ?? false;
  }
  @override
  Widget build(BuildContext context) {
    String title = widget._inputs["orderId"];
    return new WillPopScope(
        onWillPop: _onWillPop,
        child: Scaffold(
          appBar: AppBar(
            iconTheme: IconThemeData(color: widget._color1),
            title: Text(title, style: TextStyle(color: widget._color1)),
            backgroundColor: widget._color2,
          ),
          body: Builder(builder: (BuildContext context) {
            final String contentBase64 =
            base64Encode(const Utf8Encoder().convert(formHtml()));
            final String html = ('data:text/html;base64,$contentBase64');
            return WebView(
              initialUrl: html,
              javascriptMode: JavascriptMode.unrestricted,
              onWebViewCreated: (WebViewController webViewController) {
                _controller.complete(webViewController);
              },
              navigationDelegate: (NavigationRequest request) {
                if (request.url.startsWith('ios-sdk')) {
                  Navigator.pop(context, Uri.decodeFull(request.url).substring(30));
                  return NavigationDecision.prevent;
                }
                return NavigationDecision.navigate;
              },
              onPageFinished: (String url) {
                print('Page finished loading: $url');
              },
            );
          }),
        ));
  }
}

==> 0.0.2.tar.gz: lib/cashfree_pg.dart <==
library cashfree_pg;

import 'dart:async';
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:webview_flutter/webview_flutter.dart';

class CashfreePGSDK {
  Future<dynamic> doPayment(BuildContext context, Map<String, String> inputs, String mode) async {
    var completer = new Completer();
    completer.complete(Navigator.push(
        context,
        MaterialPageRoute(builder: (context) => PaymentScreen(inputs, Colors.white, Colors.black, mode))));
//        print("SDK Result : $result");
    return completer.future;
  }
  void doPaymentWithTheme(BuildContext context, Map<String, String> inputs, Color color1, Color color2, String mode) async {
    final result = await Navigator.push(
      context,
      MaterialPageRoute(builder: (context) => PaymentScreen(inputs, color1, color2, mode)),);
    print("SDK Result : $result");
  }
}


class PaymentScreen extends StatefulWidget {
  final Map<String, String> _inputs;
  final Color _color1;
  final Color _color2;
  final String _mode;
  PaymentScreen(this._inputs, this._color1, this._color2, this._mode);

  @override
  _PaymentScreenState createState() => _PaymentScreenState();
}

class _PaymentScreenState extends State<PaymentScreen> {
  final Completer<WebViewController> _controller =
  Completer<WebViewController>();

  String formHtml () {
    final url = widget._mode == "TEST" ? 'https://test.cashfree.com/billpay/checkout/post/submit' : 'https://www.cashfree.com/checkout/post/submit';
    String htmlStr = "<html>"
        "<body onload='document.order.submit()'>"
        "<form name='order' action='$url' method='post'>";
    widget._inputs.forEach((String key, String val) => htmlStr += '''<input type="hidden" name="$key" value="$val" />''');
    htmlStr +=
    "<input type='hidden' name='source' value='iossdk'/>"
        "<input type='hidden' name='hideHeader' value='1'/>"
        "</form>"
        "</body>"
        "</html>";
    print(htmlStr);
    return htmlStr;
  }

  _PaymentScreenState();
  Future<bool> _onWillPop() {
    return showDialog(
      context: context,
      builder: (context) => new AlertDialog(
        title: new Text('Are you sure?'),
        content: new Text('Do you want to abort payment'),
        actions: <Widget>[
          new FlatButton(
            onPressed: () => Navigator.of(context).pop(false),
            child: new Text('No'),
          ),
          new FlatButton(
            onPressed: () => Navigator.of(context).pop(true),
            child: new Text('Yes'),
          ),
        ],
      ),
    ) ?? false;
  }
  @override
  Widget build(BuildContext context) {
    String title = widget._inputs["orderId"];
    return new WillPopScope(
        onWillPop: _onWillPop,
        child: Scaffold(
          appBar: AppBar(
            iconTheme: IconThemeData(color: widget._color1),
            title: Text(title, style: TextStyle(color: widget._color1)),
            backgroundColor: widget._color2,
          ),
          body: Builder(builder: (BuildContext context) {
            final String contentBase64 =
            base64Encode(const Utf8Encoder().convert(formHtml()));
            final String html = ('data:text/html;base64,$contentBase64');
            return WebView(
              initialUrl: html,
              javascriptMode: JavascriptMode.unrestricted,
              onWebViewCreated: (WebViewController webViewController) {
                _controller.complete(webViewController);
              },
              navigationDelegate: (NavigationRequest request) {
                if (request.url.startsWith('ios-sdk')) {
                  Navigator.pop(context, Uri.decodeFull(request.url).substring(30));
                  return NavigationDecision.prevent;
                }
                return NavigationDecision.navigate;
              },
              onPageFinished: (String url) {
                print('Page finished loading: $url');
              },
            );
          }),
        ));
  }
}
